//download.js v4.2, by dandavis; 2008-2016. [CCBY2] see http://danml.com/download.html for tests/usage
// v1 landed a FF+Chrome compat way of downloading strings to local un-named files, upgraded to use a hidden frame and optional mime
// v2 added named files via a[download], msSaveBlob, IE (10+) support, and window.URL support for larger+faster saves than dataURLs
// v3 added dataURL and Blob Input, bind-toggle arity, and legacy dataURL fallback was improved with force-download mime and base64 support. 3.1 improved safari handling.
// v4 adds AMD/UMD, commonJS, and plain browser support
// v4.1 adds url download capability via solo URL argument (same domain/CORS only)
// v4.2 adds semantic variable names, long (over 2MB) dataURL support, and hidden by default temp anchors
// https://github.com/rndme/download

(function (root, factory) {
	if (typeof define === 'function' && define.amd) {
		// AMD. Register as an anonymous module.
		define([], factory);
	} else if (typeof exports === 'object') {
		// Node. Does not work with strict CommonJS, but
		// only CommonJS-like environments that support module.exports,
		// like Node.
		module.exports = factory();
	} else {
		// Browser globals (root is window)
		root.download = factory();
  }
}(this, function () {

	return function download(data, strFileName, strMimeType) {

		var self = window, // this script is only for browsers anyway...
			defaultMime = "application/octet-stream", // this default mime also triggers iframe downloads
			mimeType = strMimeType || defaultMime,
			payload = data,
			url = !strFileName && !strMimeType && payload,
			anchor = document.createElement("a"),
			toString = function(a){return String(a);},
			myBlob = (self.Blob || self.MozBlob || self.WebKitBlob || toString),
			fileName = strFileName || "download",
			blob,
			reader;
			myBlob= myBlob.call ? myBlob.bind(self) : Blob ;
	  
		if(String(this)==="true"){ //reverse arguments, allowing download.bind(true, "text/xml", "export.xml") to act as a callback
			payload=[payload, mimeType];
			mimeType=payload[0];
			payload=payload[1];
		}


		if(url && url.length< 2048){ // if no filename and no mime, assume a url was passed as the only argument
			fileName = url.split("/").pop().split("?")[0];
			anchor.href = url; // assign href prop to temp anchor
		  	if(anchor.href.indexOf(url) !== -1){ // if the browser determines that it's a potentially valid url path:
        		var ajax=new XMLHttpRequest();
        		ajax.open( "GET", url, true);
        		ajax.responseType = 'blob';
        		ajax.onload= function(e){ 
				  download(e.target.response, fileName, defaultMime);
				};
        		setTimeout(function(){ ajax.send();}, 0); // allows setting custom ajax headers using the return:
			    return ajax;
			} // end if valid url?
		} // end if url?


		//go ahead and download dataURLs right away
		if(/^data\:[\w+\-]+\/[\w+\-]+[,;]/.test(payload)){
		
			if(payload.length > (1024*1024*1.999) && myBlob !== toString ){
				payload=dataUrlToBlob(payload);
				mimeType=payload.type || defaultMime;
			}else{			
				return navigator.msSaveBlob ?  // IE10 can't do a[download], only Blobs:
					navigator.msSaveBlob(dataUrlToBlob(payload), fileName) :
					saver(payload) ; // everyone else can save dataURLs un-processed
			}
			
		}//end if dataURL passed?

		blob = payload instanceof myBlob ?
			payload :
			new myBlob([payload], {type: mimeType}) ;


		function dataUrlToBlob(strUrl) {
			var parts= strUrl.split(/[:;,]/),
			type= parts[1],
			decoder= parts[2] == "base64" ? atob : decodeURIComponent,
			binData= decoder( parts.pop() ),
			mx= binData.length,
			i= 0,
			uiArr= new Uint8Array(mx);

			for(i;i<mx;++i) uiArr[i]= binData.charCodeAt(i);

			return new myBlob([uiArr], {type: type});
		 }

		function saver(url, winMode){

			if ('download' in anchor) { //html5 A[download]
				anchor.href = url;
				anchor.setAttribute("download", fileName);
				anchor.className = "download-js-link";
				anchor.innerHTML = "downloading...";
				anchor.style.display = "none";
				document.body.appendChild(anchor);
				setTimeout(function() {
					anchor.click();
					document.body.removeChild(anchor);
					if(winMode===true){setTimeout(function(){ self.URL.revokeObjectURL(anchor.href);}, 250 );}
				}, 66);
				return true;
			}

			// handle non-a[download] safari as best we can:
			if(/(Version)\/(\d+)\.(\d+)(?:\.(\d+))?.*Safari\//.test(navigator.userAgent)) {
				url=url.replace(/^data:([\w\/\-\+]+)/, defaultMime);
				if(!window.open(url)){ // popup blocked, offer direct download:
					if(confirm("Displaying New Document\n\nUse Save As... to download, then click back to return to this page.")){ location.href=url; }
				}
				return true;
			}

			//do iframe dataURL download (old ch+FF):
			var f = document.createElement("iframe");
			document.body.appendChild(f);

			if(!winMode){ // force a mime that will download:
				url="data:"+url.replace(/^data:([\w\/\-\+]+)/, defaultMime);
			}
			f.src=url;
			setTimeout(function(){ document.body.removeChild(f); }, 333);

		}//end saver




		if (navigator.msSaveBlob) { // IE10+ : (has Blob, but not a[download] or URL)
			return navigator.msSaveBlob(blob, fileName);
		}

		if(self.URL){ // simple fast and modern way using Blob and URL:
			saver(self.URL.createObjectURL(blob), true);
		}else{
			// handle non-Blob()+non-URL browsers:
			if(typeof blob === "string" || blob.constructor===toString ){
				try{
					return saver( "data:" +  mimeType   + ";base64,"  +  self.btoa(blob)  );
				}catch(y){
					return saver( "data:" +  mimeType   + "," + encodeURIComponent(blob)  );
				}
			}

			// Blob but not URL support:
			reader=new FileReader();
			reader.onload=function(e){
				saver(this.result);
			};
			reader.readAsDataURL(blob);
		}
		return true;
	}; /* end download() */
}));
﻿function openFMWS(){
    var websocket = new WebSocket("wss://example.com:10000");
    websocket.binaryType = "arraybuffer";
    websocket.onmessage = function(evt) { onMessage(evt) };
    websocket.onerror = function(evt) { onError(evt) };
    websocket.onopen = function(evt) { onOpen(evt) };
    var rcd = document.getElementById("confirmrcd");
    rcd.addEventListener("click",RCD,false);
    var rls = document.getElementById("RemoteLS");
    rls.addEventListener("click",RLS,false);
    var dwnload = document.getElementById("download");
    dwnload.addEventListener("click",DOWNLOAD,false);
    var upld = document.getElementById("upload");
    upld.addEventListener("click",UPLOAD,false);
    var blob =  new Blob([""],{type: "application/octet-stream"});
    var nme;

    function onOpen(evt){
        var luser = document.getElementById("lusername").value;
        var ruser = document.getElementById("rusername").value;
        var pwd = document.getElementById("password").value;
        console.log("Connecting.. ");
        var packet = ("[CONN]"+"[11111]"+luser+"[11111]"+pwd);
        websocket.send(packet);
        console.log("Connected.");
    }
    function onMessage(evt) {
	  var luser = document.getElementById("lusername").value;
      if(evt.data.indexOf('[00000]')>=0){
        var ar = evt.data.split('[11111]');
        var cde = ar[0];
        console.log(cde);
        if (cde.indexOf("[RETLIST]")>=0){
          var dat = ar[1];
          document.getElementById("remo").value = evt.data;
          console.log(dat);
        }else if(cde.indexOf("[RETDOWN]")>=0){
          var da = evt.data.split('[00000]');
          if (evt.data.indexOf('[FILE TRANSFER COMPLETE]')>=0){
                        var xdat = evt.data.split("[22222]");
			var url = xdat[2];
			console.log("url:" + url);
			var x=new XMLHttpRequest();
			x.onreadystatechange = function() {
			  if (x.readyState == XMLHttpRequest.DONE) {
				websocket.send('[PURGE]'+"[11111]" + luser + "[11111]" + xdat[1]);
                console.log("Finshed...");
			  }
			}
			x.open("GET", url, true);
			x.responseType = 'blob';
			x.onload=function(e){download(x.response, xdat[1], "application/octet-stream" ); }
			console.log("Downloading...");
			x.send();
          }
    }
    }
    }
    function onError(evt) {
        console.log(evt);
    }


    function UPLOAD(){
        var luser = document.getElementById("lusername").value;
        var ruser = document.getElementById("rusername").value;
        var pwd = document.getElementById("password").value;
        var reader  = new FileReader();
        var file    = document.getElementById('uploadfile').files[0];
        reader.onloadend = function () {
            console.log("file name is " + file.name);
            var msg = reader.result.split(';base64,');
            var dat = msg[1];
            websocket.send("[UPLOAD]" + "[11111]" + ruser + "[11111]" + file.name + "[22222]" + dat);
            websocket.send("[UPLOAD]"+"[11111]"+ruser+"[11111]"+ "[FILE TRANSFER COMPLETE]" + "[22222]"+ "[NULL]");
            alert("file transferred!");
        }
        if (file) {
            reader.readAsDataURL(file);
        }
    }

    function RCD(){
      var luser = document.getElementById("lusername").value;
      var ruser = document.getElementById("rusername").value;
      var pwd = document.getElementById("password").value;
      var targetdir = document.getElementById("changeremotedir").value;
      websocket.send('[TRANSVERSE]'+"[11111]"+ ruser + "[11111]" + targetdir);
      RLS();
    }

    function RLS(){
      var luser = document.getElementById("lusername").value;
      var ruser = document.getElementById("rusername").value;
      var pwd = document.getElementById("password").value;
      websocket.send('[LIST]'+"[11111]"+ruser+"[11111]"+"[NULL]");
    }

    function DOWNLOAD(){
      var luser = document.getElementById("lusername").value;
      var ruser = document.getElementById("rusername").value;
      var pwd = document.getElementById("password").value;
      var targetdir = document.getElementById("downloadfile").value;
      websocket.send('[DOWNLOAD]'+"[11111]" + ruser + "[11111]" + targetdir);
    }
}

/* mousetrap v1.5.3 craig.is/killing/mice */
(function(C,r,g){function t(a,b,h){a.addEventListener?a.addEventListener(b,h,!1):a.attachEvent("on"+b,h)}function x(a){if("keypress"==a.type){var b=String.fromCharCode(a.which);a.shiftKey||(b=b.toLowerCase());return b}return l[a.which]?l[a.which]:p[a.which]?p[a.which]:String.fromCharCode(a.which).toLowerCase()}function D(a){var b=[];a.shiftKey&&b.push("shift");a.altKey&&b.push("alt");a.ctrlKey&&b.push("ctrl");a.metaKey&&b.push("meta");return b}function u(a){return"shift"==a||"ctrl"==a||"alt"==a||
"meta"==a}function y(a,b){var h,c,e,g=[];h=a;"+"===h?h=["+"]:(h=h.replace(/\+{2}/g,"+plus"),h=h.split("+"));for(e=0;e<h.length;++e)c=h[e],z[c]&&(c=z[c]),b&&"keypress"!=b&&A[c]&&(c=A[c],g.push("shift")),u(c)&&g.push(c);h=c;e=b;if(!e){if(!k){k={};for(var m in l)95<m&&112>m||l.hasOwnProperty(m)&&(k[l[m]]=m)}e=k[h]?"keydown":"keypress"}"keypress"==e&&g.length&&(e="keydown");return{key:c,modifiers:g,action:e}}function B(a,b){return null===a||a===r?!1:a===b?!0:B(a.parentNode,b)}function c(a){function b(a){a=
a||{};var b=!1,n;for(n in q)a[n]?b=!0:q[n]=0;b||(v=!1)}function h(a,b,n,f,c,h){var g,e,l=[],m=n.type;if(!d._callbacks[a])return[];"keyup"==m&&u(a)&&(b=[a]);for(g=0;g<d._callbacks[a].length;++g)if(e=d._callbacks[a][g],(f||!e.seq||q[e.seq]==e.level)&&m==e.action){var k;(k="keypress"==m&&!n.metaKey&&!n.ctrlKey)||(k=e.modifiers,k=b.sort().join(",")===k.sort().join(","));k&&(k=f&&e.seq==f&&e.level==h,(!f&&e.combo==c||k)&&d._callbacks[a].splice(g,1),l.push(e))}return l}function g(a,b,n,f){d.stopCallback(b,
b.target||b.srcElement,n,f)||!1!==a(b,n)||(b.preventDefault?b.preventDefault():b.returnValue=!1,b.stopPropagation?b.stopPropagation():b.cancelBubble=!0)}function e(a){"number"!==typeof a.which&&(a.which=a.keyCode);var b=x(a);b&&("keyup"==a.type&&w===b?w=!1:d.handleKey(b,D(a),a))}function l(a,c,n,f){function e(c){return function(){v=c;++q[a];clearTimeout(k);k=setTimeout(b,1E3)}}function h(c){g(n,c,a);"keyup"!==f&&(w=x(c));setTimeout(b,10)}for(var d=q[a]=0;d<c.length;++d){var p=d+1===c.length?h:e(f||
y(c[d+1]).action);m(c[d],p,f,a,d)}}function m(a,b,c,f,e){d._directMap[a+":"+c]=b;a=a.replace(/\s+/g," ");var g=a.split(" ");1<g.length?l(a,g,b,c):(c=y(a,c),d._callbacks[c.key]=d._callbacks[c.key]||[],h(c.key,c.modifiers,{type:c.action},f,a,e),d._callbacks[c.key][f?"unshift":"push"]({callback:b,modifiers:c.modifiers,action:c.action,seq:f,level:e,combo:a}))}var d=this;a=a||r;if(!(d instanceof c))return new c(a);d.target=a;d._callbacks={};d._directMap={};var q={},k,w=!1,p=!1,v=!1;d._handleKey=function(a,
c,e){var f=h(a,c,e),d;c={};var k=0,l=!1;for(d=0;d<f.length;++d)f[d].seq&&(k=Math.max(k,f[d].level));for(d=0;d<f.length;++d)f[d].seq?f[d].level==k&&(l=!0,c[f[d].seq]=1,g(f[d].callback,e,f[d].combo,f[d].seq)):l||g(f[d].callback,e,f[d].combo);f="keypress"==e.type&&p;e.type!=v||u(a)||f||b(c);p=l&&"keydown"==e.type};d._bindMultiple=function(a,b,c){for(var d=0;d<a.length;++d)m(a[d],b,c)};t(a,"keypress",e);t(a,"keydown",e);t(a,"keyup",e)}var l={8:"backspace",9:"tab",13:"enter",16:"shift",17:"ctrl",18:"alt",
20:"capslock",27:"esc",32:"space",33:"pageup",34:"pagedown",35:"end",36:"home",37:"left",38:"up",39:"right",40:"down",45:"ins",46:"del",91:"meta",93:"meta",224:"meta"},p={106:"*",107:"+",109:"-",110:".",111:"/",186:";",187:"=",188:",",189:"-",190:".",191:"/",192:"`",219:"[",220:"\\",221:"]",222:"'"},A={"~":"`","!":"1","@":"2","#":"3",$:"4","%":"5","^":"6","&":"7","*":"8","(":"9",")":"0",_:"-","+":"=",":":";",'"':"'","<":",",">":".","?":"/","|":"\\"},z={option:"alt",command:"meta","return":"enter",
escape:"esc",plus:"+",mod:/Mac|iPod|iPhone|iPad/.test(navigator.platform)?"meta":"ctrl"},k;for(g=1;20>g;++g)l[111+g]="f"+g;for(g=0;9>=g;++g)l[g+96]=g;c.prototype.bind=function(a,b,c){a=a instanceof Array?a:[a];this._bindMultiple.call(this,a,b,c);return this};c.prototype.unbind=function(a,b){return this.bind.call(this,a,function(){},b)};c.prototype.trigger=function(a,b){if(this._directMap[a+":"+b])this._directMap[a+":"+b]({},a);return this};c.prototype.reset=function(){this._callbacks={};this._directMap=
{};return this};c.prototype.stopCallback=function(a,b){return-1<(" "+b.className+" ").indexOf(" mousetrap ")||B(b,this.target)?!1:"INPUT"==b.tagName||"SELECT"==b.tagName||"TEXTAREA"==b.tagName||b.isContentEditable};c.prototype.handleKey=function(){return this._handleKey.apply(this,arguments)};c.init=function(){var a=c(r),b;for(b in a)"_"!==b.charAt(0)&&(c[b]=function(b){return function(){return a[b].apply(a,arguments)}}(b))};c.init();C.Mousetrap=c;"undefined"!==typeof module&&module.exports&&(module.exports=
c);"function"===typeof define&&define.amd&&define(function(){return c})})(window,document);

//RAPTORCONNECT 6.0
//r3q13m of SOLDIERX.com
var canvas = document.getElementById('stage');
var context = canvas.getContext("2d");
var ruser;
function openWS(){
    var websocket = new WebSocket("wss://127.0.0.1:9000");
    websocket.binaryType = "arraybuffer";
    websocket.onmessage = function(evt) { onMessage(evt) };
    websocket.onerror = function(evt) { onError(evt) };
    websocket.onopen = function(evt) { onOpen(evt) };
    canvas.addEventListener("mousedown", Onmouse, true);
    canvas.addEventListener("mouseup", OnmouseUP, true);
    canvas.addEventListener("dblclick", Onmousedbl, true);
    function onOpen(evt){
        var luser = document.getElementById("lusername").value;
        ruser = document.getElementById("rusername").value;
        var pwd = document.getElementById("password").value;
        document.getElementById("Login").disabled = true;
        console.log("Connecting.. ");
        var packet = ("[CONN]"+"[11111]"+luser+"[11111]"+pwd);
        websocket.send(packet);
		console.log("Connected.");
		window.setInterval(function(){
			var packet = ("[SCRREQ]"+"[11111]"+ruser+"[11111]"+"[NULL]");
            websocket.send(packet);
        }, 1300);
    }

    function onMessage(evt) {
        if(evt.data.indexOf('[22222]')>=0){
            var ar = evt.data.split('[22222]');
            console.log(ar);
            var twi  = ar[0].split('[00000]');
            //console.log(twi)
            context.width = twi[1];
            context.height = ar[1]R
            var i = ar[2];
            console.log(context.width)
            console.log(context.height)
            var img = new Image();
            img.src = "data:image/png;base64,"+i;
            img.onload = function () {
                context.drawImage(img,0,0);
				var packet = ("[SCRREQ]"+"[11111]"+ruser+"[11111]"+"[NULL]");
                websocket.send(packet);
            } 
        }
        else {
            console.log(evt.data);
        }
    }
    
    function onError(evt) {
        console.log(evt.data);
    }
    
    //this function clears the screen when primary monitor is changed.
    function screenreset() {
        setTimeout(context.clearRect(0, 0, canvas.width, canvas.height), 5000);
    }

    //incredibly poor javascript beyond this point, but it works.

    //typing without modifiers
    Mousetrap.bind('a', function(e, combo) {
        var command = ('a' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('b', function(e, combo) {
        var command = ('b' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('c', function(e, combo) {
        var command = ('c' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('d', function(e, combo) {
        var command = ('d' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('e', function(e, combo) {
        var command = ('e' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('f', function(e, combo) {
        var command = ('f' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('g', function(e, combo) {
        var command = ('g' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('h', function(e, combo) {
        var command = ('h' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('i', function(e, combo) {
        var command = ('i' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('j', function(e, combo) {
        var command = ('j' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('k', function(e, combo) {
        var command = ('k' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('l', function(e, combo) {
        var command = ('l' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('m', function(e, combo) {
        var command = ('m' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('n', function(e, combo) {
        var command = ('n' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('o', function(e, combo) {
        var command = ('o' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('p', function(e, combo) {
        var command = ('p' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('q', function(e, combo) {
        var command = ('q' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('r', function(e, combo) {
        var command = ('r' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('s', function(e, combo) {
        var command = ('s' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('t', function(e, combo) {
        var command = ('t' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('u', function(e, combo) {
        var command = ('u' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('v', function(e, combo) {
        var command = ('v' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('w', function(e, combo) {
        var command = ('w' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('x', function(e, combo) {
        var command = ('x' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('y', function(e, combo) {
        var command = ('y' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('z', function(e, combo) {
        var command = ('z' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    //regular numbers no modfiers
    Mousetrap.bind('0', function(e, combo) {
        var command = ('0' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('1', function(e, combo) {
        var command = ('1' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('2', function(e, combo) {
        var command = ('2' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('3', function(e, combo) {
        var command = ('3' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('4', function(e, combo) {
        var command = ('4' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('5', function(e, combo) {
        var command = ('5' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('6', function(e, combo) {
        var command = ('6' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('7', function(e, combo) {
        var command = ('7' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('8', function(e, combo) {
        var command = ('8' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('9', function(e, combo) {
        var command = ('9' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    //shift support quick hack for Mousetrap.
    Mousetrap.bind('shift+a', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + 'a' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+b', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + 'b' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+c', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + 'c' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+d', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + 'd' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+e', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + 'e' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+f', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + 'f' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+g', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + 'g' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+h', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + 'h' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+i', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + 'i' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+j', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + 'j' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+k', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + 'k' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+l', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + 'l' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+m', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + 'm' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+n', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + 'n' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+o', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + 'o' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+p', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + 'p' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+q', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + 'q' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+r', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + 'r' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+s', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + 's' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+t', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + 't' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+u', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + 'u' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+v', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + 'v' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+w', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + 'w' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+x', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + 'x' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+y', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + 'y' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+z', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + 'z' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+0', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + '0' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+1', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + '1' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+2', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + '2' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+3', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + '3' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+4', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + '4' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+5', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + '5' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+6', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + '6' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+7', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + '7' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+8', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + '8' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+9', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + '9' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    //ctrl support
    Mousetrap.bind('ctrl+a', function(e, combo) {
        var command = ('CTRL' + '[22222]'  + 'a' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('ctrl+b', function(e, combo) {
        var command = ('CTRL' + '[22222]'  + 'b' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('ctrl+c', function(e, combo) {
        var command = ('CTRL' + '[22222]'  + 'c' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('ctrl+d', function(e, combo) {
        var command = ('CTRL' + '[22222]'  + 'd' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('ctrl+e', function(e, combo) {
        var command = ('CTRL' + '[22222]'  + 'e' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('ctrl+f', function(e, combo) {
        var command = ('CTRL' + '[22222]'  + 'f' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('ctrl+g', function(e, combo) {
        var command = ('CTRL' + '[22222]'  + 'g' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('ctrl+h', function(e, combo) {
        var command = ('CTRL' + '[22222]'  + 'h' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('ctrl+i', function(e, combo) {
        var command = ('CTRL' + '[22222]'  + 'i' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('ctrl+j', function(e, combo) {
        var command = ('CTRL' + '[22222]'  + 'j' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('ctrl+k', function(e, combo) {
        var command = ('CTRL' + '[22222]'  + 'k' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('ctrl+l', function(e, combo) {
        var command = ('CTRL' + '[22222]'  + 'l' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('ctrl+m', function(e, combo) {
        var command = ('CTRL' + '[22222]'  + 'm' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('ctrl+n', function(e, combo) {
        var command = ('CTRL' + '[22222]'  + 'n' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('ctrl+o', function(e, combo) {
        var command = ('CTRL' + '[22222]'  + 'o' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('ctrl+p', function(e, combo) {
        var command = ('CTRL' + '[22222]'  + 'p' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('ctrl+q', function(e, combo) {
        var command = ('CTRL' + '[22222]'  + 'q' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('ctrl+r', function(e, combo) {
        var command = ('CTRL' + '[22222]'  + 'r' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('ctrl+s', function(e, combo) {
        var command = ('CTRL' + '[22222]'  + 's' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('ctrl+t', function(e, combo) {
        var command = ('CTRL' + '[22222]'  + 't' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('ctrl+u', function(e, combo) {
        var command = ('CTRL' + '[22222]'  + 'u' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('ctrl+v', function(e, combo) {
        var command = ('CTRL' + '[22222]'  + 'v' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('ctrl+w', function(e, combo) {
        var command = ('CTRL' + '[22222]'  + 'w' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('ctrl+x', function(e, combo) {
        var command = ('CTRL' + '[22222]'  + 'x' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('ctrl+y', function(e, combo) {
        var command = ('CTRL' + '[22222]'  + 'y' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('ctrl+z', function(e, combo) {
        var command = ('CTRL' + '[22222]'  + 'z' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('ctrl+0', function(e, combo) {
        var command = ('CTRL' + '[22222]'  + '0' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('ctrl+1', function(e, combo) {
        var command = ('CTRL' + '[22222]'  + '1' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('ctrl+2', function(e, combo) {
        var command = ('CTRL' + '[22222]'  + '2' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('ctrl+3', function(e, combo) {
        var command = ('CTRL' + '[22222]'  + '3' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('ctrl+4', function(e, combo) {
        var command = ('CTRL' + '[22222]'  + '4' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('ctrl+5', function(e, combo) {
        var command = ('CTRL' + '[22222]'  + '5' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('ctrl+6', function(e, combo) {
        var command = ('CTRL' + '[22222]'  + '6' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('ctrl+7', function(e, combo) {
        var command = ('CTRL' + '[22222]'  + '7' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('ctrl+8', function(e, combo) {
        var command = ('CTRL' + '[22222]'  + '8' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('ctrl+9', function(e, combo) {
        var command = ('CTRL' + '[22222]'  + '9' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    //alt support
    Mousetrap.bind('alt+a', function(e, combo) {
        var command = ('ALT' + '[22222]'  + 'a' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('alt+b', function(e, combo) {
        var command = ('ALT' + '[22222]'  + 'b' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('alt+c', function(e, combo) {
        var command = ('ALT' + '[22222]'  + 'c' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('alt+d', function(e, combo) {
        var command = ('ALT' + '[22222]'  + 'd' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('alt+e', function(e, combo) {
        var command = ('ALT' + '[22222]'  + 'e' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('alt+f', function(e, combo) {
        var command = ('ALT' + '[22222]'  + 'f' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('alt+g', function(e, combo) {
        var command = ('ALT' + '[22222]'  + 'g' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('alt+h', function(e, combo) {
        var command = ('ALT' + '[22222]'  + 'h' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('alt+i', function(e, combo) {
        var command = ('ALT' + '[22222]'  + 'i' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('alt+j', function(e, combo) {
        var command = ('ALT' + '[22222]'  + 'j' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('alt+k', function(e, combo) {
        var command = ('ALT' + '[22222]'  + 'k' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('alt+l', function(e, combo) {
        var command = ('ALT' + '[22222]'  + 'l' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('alt+m', function(e, combo) {
        var command = ('ALT' + '[22222]'  + 'm' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('alt+n', function(e, combo) {
        var command = ('ALT' + '[22222]'  + 'n' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('alt+o', function(e, combo) {
        var command = ('ALT' + '[22222]'  + 'o' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('alt+p', function(e, combo) {
        var command = ('ALT' + '[22222]'  + 'p' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('alt+q', function(e, combo) {
        var command = ('ALT' + '[22222]'  + 'q' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('alt+r', function(e, combo) {
        var command = ('ALT' + '[22222]'  + 'r' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('alt+s', function(e, combo) {
        var command = ('ALT' + '[22222]'  + 's' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('alt+t', function(e, combo) {
        var command = ('ALT' + '[22222]'  + 't' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('alt+u', function(e, combo) {
        var command = ('ALT' + '[22222]'  + 'u' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('alt+v', function(e, combo) {
        var command = ('ALT' + '[22222]'  + 'v' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('alt+w', function(e, combo) {
        var command = ('ALT' + '[22222]'  + 'w' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('alt+x', function(e, combo) {
        var command = ('ALT' + '[22222]'  + 'x' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('alt+y', function(e, combo) {
        var command = ('ALT' + '[22222]'  + 'y' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('alt+z', function(e, combo) {
        var command = ('ALT' + '[22222]'  + 'z' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('alt+0', function(e, combo) {
        var command = ('ALT' + '[22222]'  + '0' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
        screenreset()
    },"keydown");
    Mousetrap.bind('alt+1', function(e, combo) {
        var command = ('ALT' + '[22222]'  + '1' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
        screenreset()
    },"keydown");
    Mousetrap.bind('alt+2', function(e, combo) {
        var command = ('ALT' + '[22222]'  + '2' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
        screenreset()
    },"keydown");
    Mousetrap.bind('alt+3', function(e, combo) {
        var command = ('ALT' + '[22222]'  + '3' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('alt+4', function(e, combo) {
        var command = ('ALT' + '[22222]'  + '4' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('alt+5', function(e, combo) {
        var command = ('ALT' + '[22222]'  + '5' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('alt+6', function(e, combo) {
        var command = ('ALT' + '[22222]'  + '6' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('alt+7', function(e, combo) {
        var command = ('ALT' + '[22222]'  + '7' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('alt+8', function(e, combo) {
        var command = ('ALT' + '[22222]'  + '8' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('alt+9', function(e, combo) {
        var command = ('ALT' + '[22222]'  + '9' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    //special keys
    Mousetrap.bind('backspace', function(e, combo) {
        e.preventDefault();
        var command = ("BACKSPACE" + "[22222]" + "[NULL]" + "[22222]" + "[NULL]");
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('return', function(e, combo) {
        e.preventDefault();
        var command  = ("RETURN" + "[22222]" + "[NULL]" + "[22222]" + "[NULL]");
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    //doesnt work in chrome
    Mousetrap.bind('space', function(e, combo) {
        e.preventDefault();
        var command = ("SPACE" + "[22222]" + "[NULL]" + "[22222]" + "[NULL]");
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        console.log("SPACE")
        websocket.send(packet);
    },"keydown");
    //other keys
    Mousetrap.bind('*', function(e, combo) {
        var command = ('*' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('+', function(e, combo) {
        var command = ('+' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('-', function(e, combo) {
        var command = ('-' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('.', function(e, combo) {
        var command = ('.' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('/', function(e, combo) {
        var command = ('/' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind(';', function(e, combo) {
        var command = (';' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('=', function(e, combo) {
        var command = ('=' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind(',', function(e, combo) {
        var command = (',' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('`', function(e, combo) {
        var command = ('`' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('[', function(e, combo) {
        var command = ('[' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('.', function(e, combo) {
        var command = ('.' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    //may not translate right.
    Mousetrap.bind('\\', function(e, combo) {
        var command = ('\\' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind(']', function(e, combo) {
        var command = (']' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('\'', function(e, combo) {
        var command = ('\'' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    //these may not be supported by the agent
    Mousetrap.bind('shift+`', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + '`' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+=', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + '=' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+-', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + '-' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+;', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + ';' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+\\', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + '\\' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+,', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + ',' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+.', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + '.' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+/', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + '/' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    Mousetrap.bind('shift+\'', function(e, combo) {
        var command = ('SHIFT' + '[22222]'  + '\'' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
	Mousetrap.bind('del', function(e, combo) {
        var command = ('CAD' + '[22222]'  + '[NULL]' + '[22222]' + '[NULL]');
        var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
        websocket.send(packet);
    },"keydown");
    function Onmouse(evt) {
      evt.preventDefault();
      var rect = canvas.getBoundingClientRect();
      var new_x = evt.clientX;
      var new_y = evt.clientY;
      new_x = new_x - rect.left;
      new_y = new_y - rect.top;
      new_x = Math.round( new_x );
      new_y = Math.round( new_y );
      var but = evt.button;
      //var ruser = document.getElementById("rusername").value;
      if (but == 0){
          command = ("LEFTC" + "[22222]" + new_x + "[22222]" + new_y);
          var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
          websocket.send(packet);
      } else if (but == 2){
          command = ("RIGHTC" + "[22222]" + new_x + "[22222]" + new_y);
          var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
          websocket.send(packet);
      } else {
          console.log("UNSUPPORTED MOUSE BUTTON");
      }
    }
    function Onmousedbl(evt) {
      evt.preventDefault();
      var rect = canvas.getBoundingClientRect();
      var new_x = evt.clientX;
      var new_y = evt.clientY;
      new_x = new_x - rect.left;
      new_y = new_y - rect.top;
      new_x = Math.round( new_x );
      new_y = Math.round( new_y );
      var but = evt.button;
      //var ruser = document.getElementById("rusername").value;
      if (but == 0){
          command = ("DBLLEFTC" + "[22222]" + new_x + "[22222]" + new_y);
          var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
          websocket.send(packet);
      } else if (but == 2){
          command = ("DBLRIGHTC" + "[22222]" + new_x + "[22222]" + new_y);
          var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
          websocket.send(packet);
      } else {
          console.log("UNSUPPORTED MOUSE BUTTON");
      }
    }
    function OnmouseUP(evt) {
      evt.preventDefault();
      var rect = canvas.getBoundingClientRect();
      var new_x = evt.clientX;
      var new_y = evt.clientY;
      new_x = new_x - rect.left;
      new_y = new_y - rect.top;
      new_x = Math.round( new_x );
      new_y = Math.round( new_y );
      var but = evt.button;
      command = ("RELEASE" + "[22222]" + new_x + "[22222]" + new_y);
      var packet = ("[COMMAND]"+"[11111]"+ruser + '[11111]' + command);
      websocket.send(packet);
    }
}

function INITRESET(){
    var websocket = new WebSocket("wss://127.0.0.1:8100");
    websocket.binaryType = "arraybuffer";
    websocket.onmessage = function(evt) { onMessage(evt) };
    websocket.onerror = function(evt) { onError(evt) };
    websocket.onopen = function(evt) { onOpen(evt) };
    
    function onOpen(evt){
        var email = document.getElementById("resetemail").value;
        console.log("Connecting.. ");
        var packet = ("[LOST]"+"[11111]"+email+"[11111]"+"[NULL]");
        websocket.send(packet);
        console.log("Connected.");
    }
    function onMessage(evt) {
        if(evt.data.indexOf('[00000]')>=0){
            var ar = evt.data.split('[00000]');
            var COM = ar[0];
            var data = ar[1];
            if(COM === "[RESETCODESENT]"){
                alert("A reset code has been sent to your email if it is valid. Use the reset code on the next page to reset your password.");
                websocket.close();
            }else if(COM === "[RESETCODEDENIED]"){
                alert("Something went wrong sending reset code to email.. probaly invaild email.");
                websocket.close();
            } 
        else{
            console.log(evt.data);
        }
    }
    }
    function onError(evt) {
        console.log(evt.data);
    }
            
}

function Validate(){
    var websocket = new WebSocket("wss://127.0.0.1:8100");
    websocket.binaryType = "arraybuffer";
    websocket.onmessage = function(evt) { onMessage(evt) };
    websocket.onerror = function(evt) { onError(evt) };
    websocket.onopen = function(evt) { onOpen(evt) };
    
    function onOpen(evt){
        var email = document.getElementById("REMAIL").value;
        var code = document.getElementById("RCODE").value;
        //document.getElementById("Login").disabled = true;
        console.log("Connecting.. ");
        var packet = ("[RCODE]"+"[11111]"+email+"[11111]"+code);
        websocket.send(packet);
        console.log("Connected.");
    }
    function onMessage(evt) {
        if(evt.data.indexOf('[00000]')>=0){
            var ar = evt.data.split('[00000]');
            var COM = ar[0];
            var data = ar[1];
            if(COM === "[RVAILD]"){
                alert("Reset code accepted! The next page will let you change your password.");
                activate_page("#Rsetpasswd");
                websocket.close();
            }else if(COM === "[RINVAILD]"){
                alert("Reset Code was rejected!");
                websocket.close();
            } 
        else{
            console.log(evt.data);
        }
    }
    }
    function onError(evt) {
        console.log(evt.data);
    }
}

function ChangePW(){
    var websocket = new WebSocket("wss://127.0.0.1:8100");
    websocket.binaryType = "arraybuffer";
    websocket.onmessage = function(evt) { onMessage(evt) };
    websocket.onerror = function(evt) { onError(evt) };
    websocket.onopen = function(evt) { onOpen(evt) };
    
    function onOpen(evt){
        var email = document.getElementById("REMAIL").value;
        var NewP = document.getElementById("newpassword").value;
        var ConfirmP = document.getElementById("confirmpassword").value;
        if(NewP === ConfirmP){
            console.log("Connecting.. ");
            var packet = ("[COMPRESET]"+"[11111]"+email+"[11111]"+NewP);
            websocket.send(packet);
            console.log("Connected.");
        }else{
            alert("Passwords do not match. try again.");
        }
    }
    function onMessage(evt) {
        if(evt.data.indexOf('[00000]')>=0){
            var ar = evt.data.split('[00000]');
            var COM = ar[0];
            var data = ar[1];
            if(COM === "[RESETS]"){
                alert("Password Has been changed!");
                websocket.close();
            }else if(COM === "[RESETF]"){
                alert("Reset failed for some reason!");
                websocket.close();
            } 
        else{
            console.log(evt.data);
        }
    }
    }
    function onError(evt) {
        console.log(evt.data);
    }
}

function openWS(){
    var luser;
    var websocket = new WebSocket("wss://127.0.0.1:8100");
    websocket.binaryType = "arraybuffer";
    websocket.onmessage = function(evt) { onMessage(evt) };
    websocket.onerror = function(evt) { onError(evt) };
    websocket.onopen = function(evt) { onOpen(evt) };
    var blob = new Blob([""],{type: "application/octet-stream"});
    function onOpen(evt){
        luser = document.getElementById("Username").value;
        var pwd = document.getElementById("password").value;
        document.getElementById("Login").disabled = true;
        console.log("Connecting.. ");
        var packet = ("[CONN]"+"[11111]"+luser+"[11111]"+pwd);
        websocket.send(packet);
        console.log("Connected.");
    }
    
    function onMessage(evt) {
        if(evt.data.indexOf('[00000]')>=0){
            var ar = evt.data.split('[00000]');
            var COM = ar[0];
            var data = ar[1];
            if(COM === "[RETCONN]"){
                if(data === "[ACCEPTED!]"){
                    window.location = ("127.0.0.1/Home");
                }
            }else if(COM === "[SYSTEMFAILURE]"){
                alert("System Process Failed! Please Try again!");
            } 
            
        }
    }
    
    function onError(evt) {
        console.log(evt.data);
    }
}
